## Contributing to cellfinder

Contributors to cellfinder are absolutely encouraged, whether you want to fix 
bugs, or add new features to better suit your data.

If you would like to contribute to cellfinder (or any of the upstream tools
like [brainreg](https://github.com/brainglobe/brainreg), 
[imio](https://github.com/adamltyson/imio),
[imlib](https://github.com/adamltyson/imlib) etc.) please get in touch via
[email](mailto:adam.tyson@ucl.ac.uk?subject=cellfinder-development), or 
better yet by starting a discussion on the 
[gitter channel](https://gitter.im/brainglobe/cellfinder). You might find that 
there is someone already working on something similar, and you can work 
together.

If you're not sure where to start, check out the
[issues](https://github.com/brainglobe/cellfinder/issues) (and 
the issues of the other repositories).

For a more practical guide on how to contribute, such as setting up a 
development environment, please see 
[here](https://docs.brainglobe.info/cellfinder/contributing).